@@ -8,6 +8,7 @@ import time
 
 # Import Salt Testing libs
 from tests.support.paths import TMP_CONF_DIR, TMP
+from tests.support.runtests import RUNTIME_VARS
 from tests.support.unit import TestCase, skipIf
 from tests.support.mock import patch
 from tests.support.case import SSHCase
@@ -39,14 +40,14 @@ class NetapiClientTest(TestCase):
         '''
         Set up a NetapiClient instance
         '''
-        opts = salt.config.client_config(os.path.join(TMP_CONF_DIR, 'master'))
+        opts = salt.config.client_config(os.path.join(RUNTIME_VARS.TMP_CONF_DIR, 'master'))
         self.netapi = salt.netapi.NetapiClient(opts)
 
     def tearDown(self):
         del self.netapi
 
     def test_local(self):
-        low = {'client': 'local', 'tgt': '*', 'fun': 'test.ping'}
+        low = {'client': 'local', 'tgt': '*', 'fun': 'test.ping', 'timeout': 300}
         low.update(self.eauth_creds)
 
         ret = self.netapi.run(low)
@@ -58,7 +59,7 @@ class NetapiClientTest(TestCase):
         self.assertEqual(ret, {'minion': True, 'sub_minion': True})
 
     def test_local_batch(self):
-        low = {'client': 'local_batch', 'tgt': '*', 'fun': 'test.ping'}
+        low = {'client': 'local_batch', 'tgt': '*', 'fun': 'test.ping', 'timeout': 300}
         low.update(self.eauth_creds)
 
         ret = self.netapi.run(low)
@@ -174,6 +175,9 @@ class NetapiSSHClientTest(SSHCase):
         opts = salt.config.client_config(os.path.join(TMP_CONF_DIR, 'master'))
         self.netapi = salt.netapi.NetapiClient(opts)
 
+        self.priv_file = os.path.join(RUNTIME_VARS.TMP_CONF_DIR, 'key_test')
+        self.rosters = os.path.join(RUNTIME_VARS.TMP_CONF_DIR)
+
         # Initialize salt-ssh
         self.run_function('test.ping')
 
@@ -193,12 +197,20 @@ class NetapiSSHClientTest(SSHCase):
         del cls.post_webserver
 
     def test_ssh(self):
-        low = {'client': 'ssh', 'tgt': 'localhost', 'fun': 'test.ping'}
+        low = {'client': 'ssh',
+               'tgt': 'localhost',
+               'fun': 'test.ping',
+               'ignore_host_keys': True,
+               'roster_file': 'roster',
+               'rosters': [self.rosters],
+               'ssh_priv': self.priv_file}
+
         low.update(self.eauth_creds)
 
         ret = self.netapi.run(low)
 
         self.assertIn('localhost', ret)
+        self.assertIn('return', ret['localhost'])
         self.assertEqual(ret['localhost']['return'], True)
         self.assertEqual(ret['localhost']['id'], 'localhost')
         self.assertEqual(ret['localhost']['fun'], 'test.ping')
