@@ -9,12 +9,10 @@ from __future__ import absolute_import, unicode_literals, print_function
 
 # Import Salt Testing Libs
 from tests.support.mixins import LoaderModuleMockMixin
-from tests.support.unit import TestCase, skipIf
+from tests.support.unit import TestCase
 from tests.support.mock import (
     MagicMock,
     patch,
-    NO_MOCK,
-    NO_MOCK_REASON
 )
 
 # Import Salt Libs
@@ -30,7 +28,6 @@ class GlusterResults(object):
 
         class list_peers(object):
             ''' results from "peer status" '''
-            pass
 
         class peer_probe(object):
             fail_cant_connect = fail_bad_hostname = '\n'.join([
@@ -434,7 +431,6 @@ xml_set_op_version_success = """
 """
 
 
-@skipIf(NO_MOCK, NO_MOCK_REASON)
 class GlusterfsTestCase(TestCase, LoaderModuleMockMixin):
 
     '''
