@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 '''
-    :codeauthor: :email:`Jayesh Kariya <jayeshk@saltstack.com>`
+    :codeauthor: Jayesh Kariya <jayeshk@saltstack.com>
 '''
 
 # Import Python Libs
@@ -8,17 +8,12 @@ from __future__ import absolute_import, unicode_literals, print_function
 
 # Import Salt Testing Libs
 from tests.support.mixins import LoaderModuleMockMixin
-from tests.support.unit import TestCase, skipIf
-from tests.support.mock import (
-    NO_MOCK,
-    NO_MOCK_REASON
-)
+from tests.support.unit import TestCase
 
 # Import Salt Libs
 import salt.modules.sdb as sdb
 
 
-@skipIf(NO_MOCK, NO_MOCK_REASON)
 class SdbTestCase(TestCase, LoaderModuleMockMixin):
     '''
     Test cases for salt.modules.sdb
